import React from 'react';
import {
    Container,
    Segment,
    Form,
    Input,
    Button,
    Checkbox,
    Grid,
    Menu,
    List
} from 'semantic-ui-react';
import {getRequest} from '../../../actions';
import ConditionField from './Condition';
import ActionSelect from './ActionSelect';
import ActionList from './ActionList';
import ShowTree from './ShowTree';

const stateDefault = ()=>({
    groups: {},
    idx: 0,
    active: 0,
    actions: [],
    showTree: false
})

class ActionLinkAdd extends React.Component {
    state = {
        ...stateDefault()
    }

    changeState = (tag, value) => {
        if(tag == 'active'){
            this.setState({
                active: value?1:0
            })
        }
    }

    addNewGroup = (data, cb = null) => {
        let devs = [];
        let {groups} = this.state
        if(data.id1.type == 'ln') devs.push(data.id1.dev)
        if(data.id2.type == 'ln') devs.push(data.id2.dev)
        
        data.id1 = {...data.id1, ...groups[data.id1.dev]}
        data.id2 = {...data.id2, ...groups[data.id2.dev]}
        delete data.id1.dev;
        delete data.id2.dev;

        for(let i in devs){
            if(devs[i] in groups) delete groups[devs[i]];
        }

        let idx = this.state.idx + 1;
        groups[`unit${idx}`] = data;

        this.setState({
            groups,
            idx
        }, ()=>{
            if(cb && typeof cb == 'function') cb();
        })
    }

    addNewAction = (data, cb=null) => {
        this.setState({
            actions: [...this.state.actions, data]
        }, ()=>{
            if(cb && typeof cb == 'function') cb();
        })
    }

    removeAction = (idx) => {
        let {actions} = this.state;
        actions.splice(idx, 1);
        this.setState({
            actions
        })
    }

    toggleShowTree = (flag) => {
        this.setState({
            showTree: flag ? true : false
        })
    }

    delGroup = (key) => {
        if(!key) return ;
        let {groups} = this.state;
        if(key in groups) delete groups[key];

        this.setState({
            groups
        })
    }

    saveLink = () => {
        let {showDialog, toggleLoading} = this.props;
        if(this.state.actions.length == 0) return showDialog('請至少加入一個動作');
        if(Object.keys(this.state.groups).length == 0) return showDialog('請建立群組');
        if(Object.keys(this.state.groups).length > 1) return showDialog('根群組數量大於一，請合併或刪除');

        let data = {
            active: this.state.active,
            action: '',
            link: {}
        }

        let act = [];
        for(let i in this.state.actions) {
            let tmp = this.state.actions[i];
            act.push(`${tmp.dev},${tmp.act},0`);
        }

        data.action = act.join('|');

        data.link = this.state.groups[Object.keys(this.state.groups)[0]];

        fetch('/api/link/addlink', getRequest(data))
            .then(response=>response.json())
            .then(json=>{
                if(json.status != 1) return showDialog(json.message);
                showDialog('新增完成');
                this.resetData()
            })
    }

    resetData = ()=>{
        this.setState({
            ...stateDefault()
        })
    }

    render() {
        let {i18n, showDialog, toggleLoading} = this.props;
        return (
            <Container>
                <Menu>
                    <Menu.Menu position="right">
                        <Menu.Item content="ShowTree" onClick={()=>{ this.toggleShowTree(1) }}/>
                        <Menu.Item content="Save" onClick={()=>{this.saveLink()}}/>
                    </Menu.Menu>
                </Menu>
                <Form as={Segment}>
                    <Form.Field>
                        <Checkbox label="啟用連動" checked={this.state.active == 1} onChange={(e,d)=>{this.changeState('active', d.checked)}} />
                    </Form.Field>
                    <Form.Field>
                        <label>建立條件群組</label>
                        <ConditionField i18n={i18n} 
                            showDialog={showDialog} 
                            toggleLoading={toggleLoading} 
                            groups={this.state.groups}
                            addNewGroup={this.addNewGroup} />
                    </Form.Field>
                    <Form.Field>
                        <label>加入動作</label>
                        <ActionSelect i18n={i18n}
                            showDialog={showDialog} 
                            toggleLoading={toggleLoading}
                            addNewAction={this.addNewAction}  />
                    </Form.Field>
                    <Form.Field>
                        <label>已選擇動作</label>
                        <ActionList i18n={i18n} list={this.state.actions} removeAction={this.removeAction} />
                    </Form.Field>
                </Form>
                <ShowTree i18n={i18n} open={this.state.showTree} data={this.state.groups} onClose={this.toggleShowTree} delItem={this.delGroup} />
            </Container>
        )
    }
}

export default ActionLinkAdd;